Learn R Programming

casimir (version 0.3.3)

check_id_vars: Coerce id columns to character

Description

Internal helper function designed to ensure that id columns are not passed as factor variables. Factor variables in id columns may cause undesired behaviour with the drop_empty_group argument.

Usage

check_id_vars(df)

Value

The input data.frame df with the id columns being no longer factor variables.

Arguments

df

An input data.frame.