Learn R Programming

casimir (version 0.3.3)

create_rank_col: Create a rank column

Description

Create a rank per document id based on score.

Usage

create_rank_col(df)

create_rank_col_dplyr(df)

Value

The input data.frame df with an additional column "rank".

Arguments

df

A data.frame with columns "doc_id", "score".

Functions

  • create_rank_col_dplyr(): Variant with internal usage of dplyr rather than collapse library.