Learn R Programming

casimir (version 0.3.3)

dnb_gold_standard: DNB gold standard data for computing evaluation metrics

Description

A subset of documents found in the catalogue of the DNB with intellectually assigned subject labels from the GND subject vocabulary. The document ids match those in the dnb_test_predictions dataset.

Usage

dnb_gold_standard

Arguments

Format

dnb_gold_standard

A data.frame with 337 rows and 2 columns:

doc_id

DNB identifier of a document in the catalogue.

label_id

DNB identifier of a concept in the GND subject vocabulary.